@@ -5,14 +5,8 @@ from ..tokens import find_tokens
 
 
 def tokenize(args):
-    texts = tokenize_(sys.stdin)
-    for text in texts:
-        print(text)
-
-
-def tokenize_(texts):
-    for text in texts:
+    for text in sys.stdin:
         tokens = find_tokens(text)
         text = ' '.join(tokens)
         if text:
-            yield text
+            print(text)
